from sports.nba.nba_team import NBA_Team


class MiamiHeat(NBA_Team):
    """
    NBA Memphis Grizzlies Static Information

    """
    full_name = "Miami Heat"
    name = "Heat"
    team_id = 1610612748

    def __init__(self):
        """
        """
        super().__init__()

