from sports.nba.nba_team import NBA_Team


class OrlandoMagic(NBA_Team):
    """
    NBA Orlando Magic Static Information

    """
    full_name = "Orlando Magic"
    name = "Magic"
    team_id = 1610612753

    def __init__(self):
        """
        """
        super().__init__()

