class Bench:
    def __init__(self):
        self.awayPitchers = []
        self.awayBatters = []
        self.awayTeamID = None
        self.homePitchers = []
        self.homeBatters = []
        self.homeTeamID = None
        self.isHomeOrAway = None
